import SwiftUI
import Dependencies

struct Fetcher {
    func fetch() async {}
}

struct FetcherDependencyKey: DependencyKey {
    static let liveValue = Fetcher()
}

extension DependencyValues {
    
    var fetcher: Fetcher {
        get { self[FetcherDependencyKey.self] }
        set { self[FetcherDependencyKey.self] = newValue }
    }
}

struct ViewModel {
    
    @Dependency(\.fetcher) var fetcher
    
    func fetch() async {
        await fetcher.fetch()
    }
}

struct ContentView: View {
    
    let model = ViewModel()
    
    var body: some View {
        VStack {
            Image(systemName: "globe")
                .imageScale(.large)
                .foregroundColor(.accentColor)
            Text("Hello, world!")
        }
        .padding()
        .task {
            await model.fetch()
        }
    }
}

